imblearn.pipeline.Pipeline
==========================

.. currentmodule:: imblearn.pipeline

.. autoclass:: Pipeline

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Pipeline.__init__
      ~Pipeline.decision_function
      ~Pipeline.fit
      ~Pipeline.fit_predict
      ~Pipeline.fit_sample
      ~Pipeline.fit_transform
      ~Pipeline.get_params
      ~Pipeline.inverse_transform
      ~Pipeline.predict
      ~Pipeline.predict_log_proba
      ~Pipeline.predict_proba
      ~Pipeline.sample
      ~Pipeline.score
      ~Pipeline.set_params
      ~Pipeline.transform
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Pipeline.classes_
      ~Pipeline.named_steps
   
   